@@ -40,7 +40,6 @@ uri
 uriType
 createdAt
 updatedAt
-tags
 '''
 
 fragment_project = f'''
@@ -87,16 +86,6 @@ effectiveUserRoles {{
 files {{
     {fragment_file}
 }}
-tags {{
-    edges {{
-        node {{
-            id
-            tag {{
-                name
-            }}
-        }}
-    }}
-}}
 '''
 
 fragment_oauth2_client_public = f'''
